# eric7.CodeFormatting.BlackFormattingAction

Module implementing an enum defining the various Black code formatting actions.

### Global Attributes

None

### Classes

BlackFormattingAction | Class defining the various Black code formatting actions.

### Functions

None

## BlackFormattingAction

Class defining the various Black code formatting actions.

### Derived from

enum.Enum

### Class Attributes

Check
Diff
Format

### Class Methods

None

### Methods

None

### Static Methods

None

Up